@@ -12,7 +12,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Array;
 
-our $VERSION = '2.021'; # VERSION
+our $VERSION = '2.022'; # VERSION
 
 use base 'PDF::API2::Basic::PDF::Objind';
 
@@ -75,12 +75,19 @@ sub removeobj {
 Returns a list of all the elements in the array. Notice that this is
 not the array itself but the elements in the array.
 
+Also available as C<elements>.
+
 =cut
 
 sub elementsof {
     return wantarray ? @{$_[0]->{' val'}} : scalar @{$_[0]->{' val'}};
 }
 
+sub elements {
+    my $self = shift();
+    return @{$self->{' val'}};
+}
+
 =head2 $a->add_elements
 
 Appends the given elements to the array. An element is only added if it
