@@ -1,7 +1,7 @@
 # Literal PDF Object for Dirty Hacks ...
 package PDF::API2::Basic::PDF::Literal;
 
-our $VERSION = '2.021'; # VERSION
+our $VERSION = '2.022'; # VERSION
 
 use base 'PDF::API2::Basic::PDF::Objind';
 
@@ -9,6 +9,7 @@ use strict;
 
 use PDF::API2::Basic::PDF::Filter;
 use PDF::API2::Basic::PDF::Name;
+use Scalar::Util qw(blessed);
 
 no warnings qw[ deprecated recursion uninitialized ];
 
@@ -58,7 +59,7 @@ sub outobjdeep
             {
                 $fh->print('<<'.join(' ', map { '/'.PDF::API2::Basic::PDF::Name::string_to_name($_).' '.$self->{$k}->{$_} } sort keys %{$self->{$k}})." >>\n");
             } 
-            elsif(UNIVERSAL::can($self->{$k},'outobj')) 
+            elsif(blessed($self->{$k}) and $self->{$k}->can('outobj'))
             {
                 $self->{$k}->outobj($fh, $pdf, %opts);
                 $fh->print("\n");
