@@ -1,6 +1,6 @@
 package PDF::API2::Resource::Font;
 
-our $VERSION = '2.021'; # VERSION
+our $VERSION = '2.022'; # VERSION
 
 use base 'PDF::API2::Resource::BaseFont';
 
@@ -11,20 +11,6 @@ use PDF::API2::Basic::PDF::Utils;
 
 no warnings qw[ deprecated recursion uninitialized ];
 
-=head1 NAME
-
-PDF::API2::Resource::Font
-
-=head1 METHODS
-
-=over
-
-=item $font->encodeByData $encoding
-
-Encodes the font in the specified byte-encoding.
-
-=cut
-
 sub encodeByData {
     my ($self,$encoding)=@_;
     my $data=$self->data;
@@ -222,13 +208,3 @@ sub remap {
 }
 
 1;
-
-__END__
-
-=back
-
-=head1 AUTHOR
-
-Alfred Reibenschuh
-
-=cut
