@@ -1,6 +1,6 @@
 package PDF::API2::Resource::XObject::Image::GD;
 
-our $VERSION = '2.021'; # VERSION
+our $VERSION = '2.022'; # VERSION
 
 use base 'PDF::API2::Resource::XObject::Image';
 
@@ -48,13 +48,13 @@ sub read_gd {
     $self->bpc(8);
     $self->colorspace('DeviceRGB');
 
-    if(UNIVERSAL::can($gd,'jpeg') && ($c > 256) && !$opts{-lossless}) {
+    if($gd->can('jpeg') && ($c > 256) && !$opts{-lossless}) {
 
         $self->filters('DCTDecode');
         $self->{' nofilt'}=1;
         $self->{' stream'}=$gd->jpeg(75);
 
-    } elsif(UNIVERSAL::can($gd,'raw')) {
+    } elsif($gd->can('raw')) {
 
         $self->filters('FlateDecode');
         $self->{' stream'}=$gd->raw;
